@@ -1,14 +1,14 @@
-# Copyrights 2007-2021 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2022 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution Log-Report. Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Log::Report::Exception;
 use vars '$VERSION';
-$VERSION = '1.33';
+$VERSION = '1.34';
 
 
 use warnings;
@@ -43,7 +43,11 @@ sub reason(;$)
 }
 
 
-sub isFatal() { is_fatal shift->{reason} }
+sub isFatal()
+{   my $self = shift;
+    my $opts = $self->report_opts;
+    exists $opts->{is_fatal} ? $opts->{is_fatal} : is_fatal $self->{reason};
+}
 
 
 sub message(;$)
